@@ -3,6 +3,9 @@ The main logic for polling, executing and reporting jobs
 """
 import os
 import platform
+import tempfile
+import shutil
+import zipfile
 from .httpclient import Session
 from .consts import NAME, VERSION
 
@@ -181,18 +184,36 @@ class Runner(Session):
             "token": job["token"],
             "state": "failed",
         })
-
         resp.raise_for_status()
 
-    def get_dependencies(self, trace, job, dependencies=None):
+    def get_dependencies(self, trace, job, build_dir):
         """
         Get the dependencies for the given job
         :param trace: trace
         :param job: gitlab job object
-        :param dependencies: optional list of earlier jobs to restrict to
+        :param build_dir: Place to unpack artifacts into
         :return:
         """
-        pass
+        for other in job["dependencies"]:
+            trace.writeline("Fetching artifacts from {}..".format(other["name"]))
+            url = self.api("jobs/{}/artifacts".format(other["id"]))
+            resp = self.get(url,
+                            stream=True,
+                            headers={
+                                "Job-Token": other["token"],
+                            })
+            resp.raise_for_status()
+            try:
+                tmpdir = tempfile.mkdtemp()
+                path = os.path.join(tmpdir, other["artifacts_file"]["filename"])
+                with open(path, 'wb') as f:
+                    resp.raw.decode_content = True
+                    shutil.copyfileobj(resp.raw, f)
+                with zipfile.ZipFile(path, mode="r") as zf:
+                    trace.writeline("Unpacking..")
+                    zf.extractall(path=build_dir)
+            finally:
+                shutil.rmtree(tmpdir)
 
     def upload(self, trace, job, archive_file):
         """
